<?php

namespace Litecms\Newproduct\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Newproduct\Models\Newproduct;

class NewproductPolicy
{

    /**
     * Determine if the given user can view the newproduct.
     *
     * @param UserPolicy $user
     * @param Newproduct $newproduct
     *
     * @return bool
     */
    public function view(UserPolicy $user, Newproduct $newproduct)
    {
        if ($user->canDo('newproduct.newproduct.view') && $user->isAdmin()) {
            return true;
        }

        return $newproduct->user_id == user_id() && $newproduct->user_type == user_type();
    }

    /**
     * Determine if the given user can create a newproduct.
     *
     * @param UserPolicy $user
     * @param Newproduct $newproduct
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('newproduct.newproduct.create');
    }

    /**
     * Determine if the given user can update the given newproduct.
     *
     * @param UserPolicy $user
     * @param Newproduct $newproduct
     *
     * @return bool
     */
    public function update(UserPolicy $user, Newproduct $newproduct)
    {
        if ($user->canDo('newproduct.newproduct.edit') && $user->isAdmin()) {
            return true;
        }

        return $newproduct->user_id == user_id() && $newproduct->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given newproduct.
     *
     * @param UserPolicy $user
     * @param Newproduct $newproduct
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Newproduct $newproduct)
    {
        return $newproduct->user_id == user_id() && $newproduct->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given newproduct.
     *
     * @param UserPolicy $user
     * @param Newproduct $newproduct
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Newproduct $newproduct)
    {
        if ($user->canDo('newproduct.newproduct.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given newproduct.
     *
     * @param UserPolicy $user
     * @param Newproduct $newproduct
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Newproduct $newproduct)
    {
        if ($user->canDo('newproduct.newproduct.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
